'use strict';

import $ from 'jquery';

/**
 * frontend javascript for sg_jobs
 */
export default class SgJobs {

	/**
	 * Kicks things off
	 */
	constructor() {
		$('.remove-file').on('click', this._removeFile);
		$('#sgjobs-joblist').on('change', '.sgjobs-select', SgJobs._filterJoblist);
		$('#apply-cover-letter').on('change', SgJobs._checkFileSize);
		$('#apply-cv').on('change', SgJobs._checkFileSize);
		$('#apply-certificate').on('change', SgJobs._checkFileSize);
		if ($('.sg-jobs-validation-error').children().length > 0) {
			this._scrollToFirstError();
		}
	}

	/**
	 * Remove file from application logic
	 *
	 * @param event
	 * @private
	 */
	_removeFile(event) {
		let currentElement = $(this);
		event.preventDefault();

		$.post(
			'?eID=sgAjax&extensionName=SgJobs&controller=Ajax%5CJoblist&action=deleteTempFile&format=json&vendorName=SGalinski',
			{
				file: currentElement.parent().children('.filename').html(),
				type: currentElement.attr('filetype')
			}
		).done(function() {
			currentElement.parent().remove();
		});
	}

	/**
	 * Scroll to the first error of the form
	 *
	 * @private
	 */
	_scrollToFirstError() {
		let $errors = $('.sg-jobs-validation-error:has(li)'),
			errorOffset = $errors.parent().offset();
		$(window).scrollTop(errorOffset.top);
	}

	/**
	 * Filter for the joblist, simply apply the form
	 *
	 * @private
	 */
	static _filterJoblist() {
		$('#sgjobs-filter').submit();
	}

	/**
	 * Check the file size of the upload fields
	 *
	 * @private
	 */
	static _checkFileSize(event) {
		if (event.currentTarget.files[0].size > document.querySelector('#maxFileSize').getAttribute('data-maxFilesize') * 1000) {
			alert(document.querySelector('#maxFileSizeMessage').getAttribute('data-maxFileSizeMessage'));
			event.currentTarget.value = '';
		}
	}
}
